@@ -14,14 +14,8 @@ def parser():
     return build_parser()
 
 
-@pytest.fixture
-def session(monkeypatch: pytest.MonkeyPatch):
-    monkeypatch.setattr("streamlink.session.Streamlink.load_builtin_plugins", lambda _: None)
-    yield Streamlink()
-
-
 @pytest.mark.filterwarnings("ignore")
-@pytest.mark.parametrize("argv,option,expected", [
+@pytest.mark.parametrize(("argv", "option", "expected"), [
     pytest.param(
         ["--locale", "xx_XX"],
         "locale",
@@ -29,16 +23,22 @@ def session(monkeypatch: pytest.MonkeyPatch):
         id="Arg+value without mapper",
     ),
     pytest.param(
-        ["--http-query-param", "foo=bar", "--http-query-param", "baz=qux"],
-        "http-query-params",
-        {"foo": "bar", "baz": "qux"},
-        id="Arg+value with dict mapper",
+        ["--http-disable-dh"],
+        "http-disable-dh",
+        True,
+        id="Arg with action=store_true",
     ),
     pytest.param(
         ["--http-no-ssl-verify"],
         "http-ssl-verify",
         False,
-        id="Arg with bool mapper",
+        id="Arg with action=store_false",
+    ),
+    pytest.param(
+        ["--http-query-param", "foo=bar", "--http-query-param", "baz=qux"],
+        "http-query-params",
+        {"foo": "bar", "baz": "qux"},
+        id="Arg+value with dict mapper",
     ),
     pytest.param(
         ["--http-ssl-cert-crt-key", "foo.crt", "bar.key"],
@@ -65,6 +65,32 @@ def test_setup_session_options(parser: ArgumentParser, session: Streamlink, argv
     assert session.get_option(option) == expected
 
 
+def test_setup_session_options_default_values(monkeypatch: pytest.MonkeyPatch, parser: ArgumentParser, session: Streamlink):
+    mock_set_option = Mock()
+    monkeypatch.setattr(session, "set_option", mock_set_option)
+    args = parser.parse_args([])
+    setup_session_options(session, args)
+    assert session.options.options == session.options.defaults
+    assert not mock_set_option.called, "Value of unset session-option arg must be None and must not call set_option()"
+
+
+@pytest.mark.parametrize(("default", "new", "expected"), [
+    pytest.param(False, None, False, id="Default False, unset"),
+    pytest.param(True, None, True, id="Default True, unset"),
+    pytest.param(False, False, False, id="Default False, set to False"),
+    pytest.param(False, True, True, id="Default False, set to True"),
+    pytest.param(True, False, False, id="Default True, set to False"),
+    pytest.param(True, True, True, id="Default True, set to True"),
+])
+def test_setup_session_options_override(monkeypatch: pytest.MonkeyPatch, session: Streamlink, default, new, expected):
+    arg = "NON_EXISTING_ARGPARSER_ARGUMENT"
+    key = "NON-EXISTING-SESSION-OPTION-KEY"
+    monkeypatch.setattr("streamlink_cli.argparser._ARGUMENT_TO_SESSIONOPTION", [(arg, key, None)])
+    session.set_option(key, default)
+    setup_session_options(session, Namespace(**{arg: new}))
+    assert session.get_option(key) == expected
+
+
 def test_cli_main_setup_session_options(monkeypatch: pytest.MonkeyPatch, parser: ArgumentParser, session: Streamlink):
     class StopTest(Exception):
         pass
